@@ -34,7 +34,7 @@ import textwrap
 import time
 from typing import List
 
-__version__ = '1.2.2'
+__version__ = '1.3.0'
 __docformat__ = "restructuredtext"
 
 # format settings
@@ -128,7 +128,7 @@ USAGE = "%(prog)s OPTIONS [REPOSITORY]"
 
 _EPILOG = textwrap.dedent("""
     git-big-picture is software libre, licensed under the GPL v3 or later license.
-    Please report bugs at https://github.com/git-big-picture/git-big-picture/issues.  Thank you!
+    Please report bugs at https://github.com/git-big-picture/git-big-picture/issues — thank you!
 """)
 
 _RIGHT_COLUMN_WRAP_WIDTH = 57
@@ -1036,7 +1036,7 @@ class CommitGraph:
         if history_direction is not None:
             rankdir = RANKDIR_OF_HISTORY_DIRECTION[history_direction]
             dot_file_lines.append(f'\trankdir="{rankdir}";')
-        for sha_one, labels, color in label_gen():
+        for sha_one, labels, color in sorted(label_gen()):
             label = '\\n'.join(labels + ((with_commit_messages or sha_ones_on_labels) and [
                 format_label(sha_one),
             ] or list()))
@@ -1051,7 +1051,7 @@ class CommitGraph:
                 sha_label = format_label(sha_one)
                 dot_file_lines.append(f'\t"{sha_one}"[label="{sha_label}"];')
         for child, self.parents in self.parents.items():
-            for p in self.parents:
+            for p in sorted(self.parents):
                 dot_file_lines.append(f'\t"{child}" -> "{p}";')
         dot_file_lines.append('}')
         return dot_file_lines
